Stan Math Library: stan/math/rev/mat/fun/to_var.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
to_var.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/typedefs.hpp>`
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/rev/mat/fun/typedefs.hpp>`
`#include <stan/math/rev/scal/fun/to_var.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
matrix_v | stan::math::to_var (const stan::math::matrix_d &m)
| Converts argument to an automatic differentiation variable. More...
matrix_v | stan::math::to_var (const matrix_v &m)
| Converts argument to an automatic differentiation variable. More...
vector_v | stan::math::to_var (const stan::math::vector_d &v)
| Converts argument to an automatic differentiation variable. More...
vector_v | stan::math::to_var (const vector_v &v)
| Converts argument to an automatic differentiation variable. More...
row_vector_v | stan::math::to_var (const stan::math::row_vector_d &rv)
| Converts argument to an automatic differentiation variable. More...
row_vector_v | stan::math::to_var (const row_vector_v &rv)
| Converts argument to an automatic differentiation variable. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.